@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/tools/qtextcodec.cpp   2.2.3   edited 2000-12-07 $
+** 
 **
 ** Implementation of QTextCodec class
 **
@@ -38,17 +38,17 @@
 #include "qtextcodec.h"
 #ifndef QT_NO_TEXTCODEC
 
-#include "qlist.h"
+#include "qinternallist.h"
 #ifndef QT_NO_CODECS
 #include "qutfcodec.h"
-#include "qgbkcodec.h"
-#include "qeucjpcodec.h"
-#include "qjiscodec.h"
-#include "qsjiscodec.h"
-#include "qeuckrcodec.h"
-#include "qbig5codec.h"
-#include "qrtlcodec.h"
-#include "qtsciicodec.h"
+//#include "qgbkcodec.h"
+//#include "qeucjpcodec.h"
+//#include "qjiscodec.h"
+//#include "qsjiscodec.h"
+//#include "qeuckrcodec.h"
+//#include "qbig5codec.h"
+//#include "qrtlcodec.h"
+//#include "qtsciicodec.h"
 #endif
 
 #include "qfile.h"
@@ -60,7 +60,7 @@
 #include <locale.h>
 
 
-static QList<QTextCodec> * all = 0;
+static QInternalList<QTextCodec> * all = 0;
 static bool destroying_is_ok; // starts out as 0
 
 /*!  Deletes all the created codecs.
@@ -84,7 +84,7 @@ void QTextCodec::deleteAllCodecs()
         return;
 
     destroying_is_ok = TRUE;
-    QList<QTextCodec> * ball = all;
+    QInternalList<QTextCodec> * ball = all;
     all = 0;
     ball->clear();
     delete ball;
@@ -101,7 +101,7 @@ static void realSetup()
     if ( destroying_is_ok )
         qWarning( "creating new codec during codec cleanup" );
 #endif
-    all = new QList<QTextCodec>;
+    all = new QInternalList<QTextCodec>;
     all->setAutoDelete( TRUE );
     setupBuiltinCodecs();
 }
@@ -354,7 +354,7 @@ QTextCodec* QTextCodec::codecForIndex(int i)
 QTextCodec* QTextCodec::codecForMib(int mib)
 {
     setup();
-    QListIterator<QTextCodec> i(*all);
+    QInternalListIterator<QTextCodec> i(*all);
     QTextCodec* result;
     for ( ; (result=i); ++i ) {
         if ( result->mibEnum()==mib )
@@ -626,7 +626,7 @@ QTextCodec* QTextCodec::codecForLocale()
 QTextCodec* QTextCodec::codecForName(const char* hint, int accuracy)
 {
     setup();
-    QListIterator<QTextCodec> i(*all);
+    QInternalListIterator<QTextCodec> i(*all);
     QTextCodec* result = 0;
     int best=accuracy;
     for ( QTextCodec* cursor; (cursor=i); ++i ) {
@@ -653,7 +653,7 @@ QTextCodec* QTextCodec::codecForName(const char* hint, int accuracy)
 QTextCodec* QTextCodec::codecForContent(const char* chars, int len)
 {
     setup();
-    QListIterator<QTextCodec> i(*all);
+    QInternalListIterator<QTextCodec> i(*all);
     QTextCodec* result = 0;
     int best=0;
     for ( QTextCodec* cursor; (cursor=i); ++i ) {
@@ -925,21 +925,21 @@ struct QMultiByteUnicodeTable {
     QMultiByteUnicodeTable* multibyte;
 };
 
+#ifndef QT_NO_CODECS
 static int getByte(char* &cursor)
 {
     int byte = 0;
     if ( *cursor ) {
         if ( cursor[1] == 'x' )
-            byte = strtol(cursor+2,&cursor,16);
+            byte = (int)strtol(cursor+2,&cursor,16);
         else if ( cursor[1] == 'd' )
-            byte = strtol(cursor+2,&cursor,10);
+            byte = (int)strtol(cursor+2,&cursor,10);
         else
-            byte = strtol(cursor+2,&cursor,8);
+            byte = (int)strtol(cursor+2,&cursor,8);
     }
     return byte&0xff;
 }
 
-#ifndef QT_NO_CODECS
 class QTextCodecFromIOD;
 
 class QTextCodecFromIODDecoder : public QTextDecoder {
@@ -1006,7 +1006,7 @@ public:
                 break;
             else if (incmap) {
                 char* cursor = line;
-                int byte,unicode=-1;
+                int byte=0,unicode=-1;
                 ushort* mb_unicode=0;
                 const int maxmb=8; // more -> we'll need to improve datastructures
                 char mb[maxmb+1];
@@ -1017,7 +1017,7 @@ public:
                         cursor[2]>='0' && cursor[2]<='9' &&
                         cursor[3]>='0' && cursor[3]<='9') {
 
-                        unicode = strtol(cursor+2,&cursor,16);
+                        unicode = (int)strtol(cursor+2,&cursor,16);
 
                     } else if (*cursor==esc) {
 
@@ -1967,7 +1967,7 @@ public:
     int heuristicNameMatch(const char* hint) const;
 
 private:
-    int forwardIndex;
+    //int forwardIndex;
 };
 
 
@@ -2054,17 +2054,17 @@ static void setupBuiltinCodecs()
         (void)new QSimpleTextCodec( i );
     } while( unicodevalues[i++].mib != LAST_MIB );
 
-    (void)new QEucJpCodec;
-    (void)new QSjisCodec;
-    (void)new QJisCodec;
-    (void)new QEucKrCodec;
-    (void)new QGbkCodec;
-    (void)new QBig5Codec;
+    //(void)new QEucJpCodec;
+    //(void)new QSjisCodec;
+    //(void)new QJisCodec;
+    //(void)new QEucKrCodec;
+    //(void)new QGbkCodec;
+    //(void)new QBig5Codec;
     (void)new QUtf8Codec;
     (void)new QUtf16Codec;
-    (void)new QHebrewCodec;
-    (void)new QArabicCodec;
-    (void)new QTsciiCodec;
+    //(void)new QHebrewCodec;
+    //(void)new QArabicCodec;
+    //(void)new QTsciiCodec;
 #endif // QT_NO_CODECS
 }
 
