@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * $Id: groupdef.h,v 1.18 2001/03/19 19:27:40 root Exp $
+ * 
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -159,9 +159,10 @@ class GroupSDict : public SDict<GroupDef>
   public:
     GroupSDict(uint size) : SDict<GroupDef>(size) {}
     virtual ~GroupSDict() {}
-    int compareItems(QCollection::Item item1,QCollection::Item item2)
+  private:
+    int compareValues(const GroupDef *item1,const GroupDef *item2) const
     {
-      return qstrcmp(((GroupDef*)item1)->groupTitle(),((GroupDef*)item2)->groupTitle());
+      return qstrcmp(item1->groupTitle(),item2->groupTitle());
     }
 };
 
@@ -169,9 +170,9 @@ class GroupSDict : public SDict<GroupDef>
 class GroupList : public QList<GroupDef>
 {
   public:
-    int compareItems(QCollection::Item item1,QCollection::Item item2)
+    int compareValues(const GroupDef *item1,const GroupDef *item2) const
     {
-      return qstrcmp(((GroupDef*)item1)->groupTitle(),((GroupDef*)item2)->groupTitle());
+      return qstrcmp(item1->groupTitle(),item2->groupTitle());
     }
 };
 
