@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2014 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -40,7 +40,6 @@ class MemberList : public QList<MemberDef>
     bool insert(uint index,const MemberDef *md);
     void inSort(const MemberDef *md);
     void append(const MemberDef *md);
-    int compareItems(QCollection::Item item1,QCollection::Item item2);
     int varCount() const       { ASSERT(m_numDecMembers!=-1); return m_varCnt;     }
     int funcCount() const      { ASSERT(m_numDecMembers!=-1); return m_funcCnt;    }
     int enumCount() const      { ASSERT(m_numDecMembers!=-1); return m_enumCnt;    }
@@ -82,6 +81,7 @@ class MemberList : public QList<MemberDef>
     void unmarshal(StorageIntf *s);
 
   private:
+    int compareValues(const MemberDef *item1,const MemberDef *item2) const;
     int m_varCnt;
     int m_funcCnt;
     int m_enumCnt;
@@ -121,7 +121,8 @@ class MemberSDict : public SDict<MemberDef>
   public:
     MemberSDict(int size=17) : SDict<MemberDef>(size) {}
     virtual ~MemberSDict() {}
-    int compareItems(QCollection::Item item1,QCollection::Item item2);
+  private:
+    int compareValues(const MemberDef *item1,const MemberDef *item2) const;
 };
 
 
